==> haskell-transformers-base-0.4.5.2-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-base
version:              0.4.5.2
visibility:           public
id:                   transformers-base-0.4.5.2-7bVZpIH19H1JaR3nyxDGa9
key:                  transformers-base-0.4.5.2-7bVZpIH19H1JaR3nyxDGa9
license:              BSD-3-Clause
copyright:
    2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:
    Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
homepage:             https://github.com/mvv/transformers-base
synopsis:             Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.

category:             Control
abi:                  77c55d9d2d9200e5fe6be47837fa4e8d
exposed:              True
exposed-modules:      Control.Monad.Base
import-dirs:          /usr/lib/ghc-8.10.3/site-local/transformers-base-0.4.5.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/transformers-base-0.4.5.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.3/transformers-base-0.4.5.2

hs-libraries:         HStransformers-base-0.4.5.2-7bVZpIH19H1JaR3nyxDGa9
depends:
    base-4.14.1.0 base-orphans-0.8.4-416cWSiku5bDoaeEDewV9e stm-2.5.0.0
    transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:
    /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock

haddock-html:         /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-base-0.4.5.2-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-base
version:              0.4.5.2
visibility:           public
id:                   transformers-base-0.4.5.2-DxpZNZ5DEbt2pX2aHWVDTz
key:                  transformers-base-0.4.5.2-DxpZNZ5DEbt2pX2aHWVDTz
license:              BSD-3-Clause
copyright:
    2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:
    Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
homepage:             https://github.com/mvv/transformers-base
synopsis:             Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.

category:             Control
abi:                  1515887632c357701c63fc35a527438a
exposed:              True
exposed-modules:      Control.Monad.Base
import-dirs:          /usr/lib/ghc-8.10.3/site-local/transformers-base-0.4.5.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/transformers-base-0.4.5.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.3/transformers-base-0.4.5.2

hs-libraries:         HStransformers-base-0.4.5.2-DxpZNZ5DEbt2pX2aHWVDTz
depends:
    base-4.14.1.0 base-orphans-0.8.4-IGWpT0teY3i5Jtd70zZv4R stm-2.5.0.0
    transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:
    /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock

haddock-html:         /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
